Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/HansKristian-Work/dxil-spirv.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHans-Kristian Arntzen <post@arntzen-software.no>2020-01-22 17:42:16 +0300
committerHans-Kristian Arntzen <post@arntzen-software.no>2020-01-22 17:42:45 +0300
commitdf7e49f3fb76ac399abcad4553c79cfff7812678 (patch)
tree0d4c062d524eb9523663809cbd01043ef68a3f69 /dxil_parser.hpp
parent8e7d12f54e4f614eeb71ad1cabe1e522aa2d2b91 (diff)
Update namespace to dxil_spv.
Diffstat (limited to 'dxil_parser.hpp')
-rw-r--r--dxil_parser.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/dxil_parser.hpp b/dxil_parser.hpp
index 92d970f..b3a7266 100644
--- a/dxil_parser.hpp
+++ b/dxil_parser.hpp
@@ -23,7 +23,7 @@
#include <stdint.h>
#include <vector>
-namespace DXIL2SPIRV
+namespace dxil_spv
{
class MemoryStream;
@@ -43,4 +43,4 @@ private:
bool parse_dxil(MemoryStream &stream);
bool parse_iosg1(MemoryStream &stream, std::vector<DXIL::IOElement> &elements);
};
-} // namespace DXIL2SPIRV \ No newline at end of file
+} // namespace dxil_spv \ No newline at end of file